# coding: utf-8

"""
    CardPay REST API

    Welcome to the CardPay REST API. The CardPay API uses HTTP verbs and a [REST](https://en.wikipedia.org/wiki/Representational_state_transfer) resources endpoint structure (see more info about REST). Request and response payloads are formatted as JSON. Merchant uses API to create payments, refunds, payouts or recurrings, check or update transaction status and get information about created transactions. In API authentication process based on [OAuth 2.0](https://oauth.net/2/) standard. For recent changes see changelog section.  # noqa: E501

    OpenAPI spec version: 3.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

import six


class ScheduleOption(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {"amount": "float", "installments": "int"}

    attribute_map = {"amount": "amount", "installments": "installments"}

    def __init__(self, amount=None, installments=None):  # noqa: E501
        """ScheduleOption - a model defined in Swagger"""  # noqa: E501

        self._amount = None
        self._installments = None
        self.discriminator = None

        if amount is not None:
            self.amount = amount
        if installments is not None:
            self.installments = installments

    @property
    def amount(self):
        """Gets the amount of this ScheduleOption.  # noqa: E501

        Amount per one payment.  # noqa: E501

        :return: The amount of this ScheduleOption.  # noqa: E501
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this ScheduleOption.

        Amount per one payment.  # noqa: E501

        :param amount: The amount of this ScheduleOption.  # noqa: E501
        :type: float
        """

        self._amount = amount

    @property
    def installments(self):
        """Gets the installments of this ScheduleOption.  # noqa: E501

        Number of payments, can be 3-12.  # noqa: E501

        :return: The installments of this ScheduleOption.  # noqa: E501
        :rtype: int
        """
        return self._installments

    @installments.setter
    def installments(self, installments):
        """Sets the installments of this ScheduleOption.

        Number of payments, can be 3-12.  # noqa: E501

        :param installments: The installments of this ScheduleOption.  # noqa: E501
        :type: int
        """

        self._installments = installments

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                if value is not None:
                    result[attr] = value
        if issubclass(ScheduleOption, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScheduleOption):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
